


require! {
	"gulp":					gulp
	"gulp-install":			install
	"gulp-conflict":		conflict
	"gulp-template":		template
	"gulp-rename":			rename
	"gulp-util":			gutil
	"underscore.string":	_

	"inquirer":				inquirer
	"path":					path
}



defaults = do ->
	workingDirName = process.cwd! |> path.basename
	user = {}

	if process.platform is "win32"
		homeDir = process.env.USERPROFILE
		osUserName = process.env.USERNAME or path.basename(homeDir).to-lower-case!
	else
		homeDir = process.env.HOME or process.env.HOMEPATH
		osUserName = homeDir and homeDir.split("/").pop! or "root"

	configFile = path.join(homeDir, ".gitconfig")

	if require("fs").exists-sync(configFile) then user = require("iniparser").parse-sync(configFile).user

	appName:		workingDirName,
	userName:		osUserName or (user.name || "").to-lower-case!.replace(/\s/g, ""),
	authorName:		user.name or "",
	authorEmail:	user.email or ""



gulp.task "default", (done) ->
	prompts =
		*	message:	"Human-readable name of your project:"						name:	"appNameReadable"				default:	_.humanize defaults.appName
		*	message:	"Slugified name of your project:"							name:	"appName"						default:	_.slugify defaults.appName
		*	message:	"Project Path:"												name:	"appPath"						default:	process.cwd!
		*	message:	"Description:"												name:	"appDescription"				default:	"Totally awesome app."
		*	message:	"Initial Version:"											name:	"appVersion"					default:	"0.1.0"
		*	message:	"Author name:"												name:	"authorName"					default:	defaults.authorName
		*	message:	"Author email:"												name:	"authorEmail"					default:	defaults.authorEmail

		*	message:	"GitHub username:"											name:	"githubUserName"				default:	defaults.userName
		*	message:	"GitHub scope:"												name:	"githubScope"					default:	defaults.userName

		*	message:	"Firebase app name:"										name:	"firebaseAppName"				default:	defaults.appName

		*	message:	"Okay to start?"											name:	"moveon"						type:		"confirm"



	inquirer.prompt prompts, (answers) ->
		if not answers.moveon then done!
		else
			answers.appNameSlug = _.slugify answers.appName

			gulp.src [__dirname + "/templates/**", "!**/gradlew"] dot:yes
				.pipe template answers
				.on 'error' gutil.log
				.pipe rename (file) -> file.basename = "." + file.basename.slice 1 if file.basename[0] is "_"
				.on 'error' gutil.log
				# .pipe conflict "./"																						# TODO maybe delete conflict() ?
				.pipe gulp.dest "./"
				.on 'error' gutil.log
				.pipe install!
				.on "end", -> done!
